@@ -6,7 +6,7 @@ from streamlink.plugin.api.utils import parse_json
 from streamlink.stream import HLSStream, RTMPStream, HTTPStream
 
 API_URL = "https://api-dsa.17app.co/api/v1/liveStreams/isUserOnLiveStream"
-ROOM_URL = "http://17app.co/share/live/{0}"
+ROOM_URL = "http://17.media/share/live/{0}"
 
 _url_re = re.compile(r"http://(17app.co|17.media)/share/(?P<page>[^/]+)/(?P<channel>[^/&?]+)")
 _userid_re = re.compile(r'"userID"\s*:\s*"(.+?)"')
@@ -31,6 +31,7 @@ class App17(Plugin):
     def _get_streams(self):
         match = _url_re.match(self.url)
         page = match.group("page")
+        channel = match.group("channel")
 
         http.headers.update({'User-Agent': useragents.CHROME})
 
@@ -44,6 +45,16 @@ class App17(Plugin):
                 self.logger.info("Stream currently unavailable.")
                 return
 
+            url = ROOM_URL.format(rid)
+            res = http.get(url)
+        elif page == 'profile':
+            api = http.post(API_URL, data={"targetUserID": channel})
+            data = http.json(api, schema=_user_api_schema)
+            rid = data["liveStreamID"]
+            if rid == 0:
+                self.logger.info("Stream currently unavailable.")
+                return
+
             url = ROOM_URL.format(rid)
             res = http.get(url)
         else:
@@ -67,13 +78,16 @@ class App17(Plugin):
         else:
             yield "live", HTTPStream(self.session, url)
 
-        prefix = url.replace("rtmp:", "http:").replace(".flv", ".m3u8")
-        if '.m3u8' not in prefix:
-            url = prefix + "/playlist.m3u8"
+        if '17app.co' in url:
+            prefix = url.replace("rtmp:", "http:").replace(".flv", "/playlist.m3u8")
+            if '/playlist.m3u8' not in prefix:
+                url = prefix + "/playlist.m3u8"
+            else:
+                url = prefix
             for stream in HLSStream.parse_variant_playlist(self.session, url).items():
                 yield stream
         else:
-            url = prefix
+            url = url.replace(".flv", ".m3u8")
             yield "live", HLSStream(self.session, url)
 
 
